@@ -14,11 +14,11 @@ plot_issues_over_time <- function(petitions) {
     aes(
       x=created_POSIXct,
       y=issue,
-      size=signature.count,
+      size=signatureCount,
       color=status
     )
   ) +
     geom_point() +
     labs(x="Created", y="Issues")
 
-}
\ No newline at end of file
+}
